searchData={"items":[{"type":"module","title":"Anthropix","doc":"![Anthropix](https://raw.githubusercontent.com/lebrunel/anthropix/main/media/poster.webp)\n\n![License](https://img.shields.io/github/license/lebrunel/anthropix?color=informational)\n\nAnthropix is an open-source Elixir client for the Anthropic API, providing a\nsimple and convenient way to integrate Claude, Anthropic's powerful language\nmodel, into your applications.\n\n- ✅ API client fully implementing the [Anthropic API](https://docs.anthropic.com/claude/reference/getting-started-with-the-api)\n- 🧰 Tool use (function calling)\n- 🧠 Extended thinking\n- ⚡ Prompt caching\n- 📦 Message batching (`Anthropix.Batch`)\n- 🛜 Streaming API requests\n  - Stream to an Enumerable\n  - Or stream messages to any Elixir process","ref":"Anthropix.html"},{"type":"module","title":"Installation - Anthropix","doc":"The package can be installed by adding `anthropix` to your list of\ndependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:anthropix, \"~> 0.6.2\"}\n  ]\nend\n```","ref":"Anthropix.html#module-installation"},{"type":"module","title":"Quickstart - Anthropix","doc":"> #### Beta features {: .info}\n>\n> Anthropic frequently ship new features under a beta flag, requiring headers\nto be added to your requests to take advantage of the feature.\n>\n> If required, beta headers can be added with `init/2`.\n>\n> ```elixir\n> client = Anthropix.init(beta: [\"output-128k-2025-02-19\"])\n> ```","ref":"Anthropix.html#module-quickstart"},{"type":"module","title":"Initiate a client. - Anthropix","doc":"See `Anthropix.init/2`.\n\n```elixir\niex> client = Anthropix.init(api_key)\n```","ref":"Anthropix.html#module-initiate-a-client"},{"type":"module","title":"Chat with Claude - Anthropix","doc":"See `Anthropix.chat/2`.\n\n```elixir\niex> messages = [\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"content\" => [%{\n  \"type\" => \"text\",\n  \"text\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}], ...}}\n```","ref":"Anthropix.html#module-chat-with-claude"},{"type":"module","title":"Streaming - Anthropix","doc":"A streaming request can be initiated by setting the `:stream` option.\n\nWhen `:stream` is true a lazy `t:Enumerable.t/0` is returned which can be used\nwith any `Stream` functions.\n\n```elixir\niex> {:ok, stream} = Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...>   stream: true,\n...> ])\n{:ok, #Function<52.53678557/2 in Stream.resource/3>}\n\niex> stream\n...> |> Stream.each(&update_ui_with_chunk/1)\n...> |> Stream.run()\n:ok\n```\n\nBecause the above approach builds the `t:Enumerable.t/0` by calling `receive`,\nusing this approach inside GenServer callbacks may cause the GenServer to\nmisbehave. Setting the `:stream` option to a `t:pid/0` returns a `t:Task.t/0`\nwhich will send messages to the specified process.","ref":"Anthropix.html#module-streaming"},{"type":"function","title":"Anthropix.chat/2","doc":"Chat with Claude. Send a list of structured input messages with text and/or\nimage content, and Claude will generate the next message in the conversation.","ref":"Anthropix.html#chat/2"},{"type":"function","title":"Options - Anthropix.chat/2","doc":"* `:model` (`t:String.t/0`) - Required. The model that will complete your prompt.\n* `:messages` (list of `t:map/0`) - Required. Input messages.\n* `:system` - System prompt.\n* `:thinking` (`t:map/0`) - Enable thinking mode and the budget of tokens to use.\n  * `:type`\n  * `:budget_tokens` (`t:non_neg_integer/0`)\n* `:max_tokens` (`t:integer/0`) - The maximum number of tokens to generate before stopping. The default value is `4096`.\n* `:metadata` - A map describing metadata about the request.\n* `:stop_sequences` (list of `t:String.t/0`) - Custom text sequences that will cause the model to stop generating.\n* `:stream` - Whether to incrementally stream the response using server-sent events. The default value is `false`.\n* `:temperature` (`t:float/0`) - Amount of randomness injected into the response.\n* `:tools` (list of `t:map/0`) - A list of tools the model may call.\n* `:tool_choice` (`t:map/0`) - How to use the provided tools.\n  * `:type` (`t:String.t/0`) - Required. One of `auto`, `any` or `tool`.\n  * `:name` (`t:String.t/0`) - The name of the tool to use.\n  * `:disable_parallel_tool_use` (`t:boolean/0`)\n* `:top_k` (`t:integer/0`) - Only sample from the top K options for each subsequent token.\n* `:top_p` (`t:float/0`) - Amount of randomness injected into the response.","ref":"Anthropix.html#chat/2-options"},{"type":"function","title":"Message structure - Anthropix.chat/2","doc":"Each message is a map with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `user` or `assistant`.\n* `:content` - Required. Message content, either a single string or an array of content blocks.","ref":"Anthropix.html#chat/2-message-structure"},{"type":"function","title":"Tool structure - Anthropix.chat/2","doc":"Each tool is a map with the following fields:\n\n* `:name` (`t:String.t/0`) - Required. Name of the tool.\n* `:description` (`t:String.t/0`) - Required. Description of the tool\n* `:input_schema` - Required. JSON schema for the tool input shape that the model will produce in tool_use output content blocks.\n* `:cache_control` - Cache-control parameter.","ref":"Anthropix.html#chat/2-tool-structure"},{"type":"function","title":"Examples - Anthropix.chat/2","doc":"```elixir\niex> messages = [\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"content\" => [%{\n  \"type\" => \"text\",\n  \"text\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}], ...}}\n\n# Passing true to the :stream option initiates an async streaming request.\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...>   stream: true,\n...> ])\n{:ok, #Function<52.53678557/2 in Stream.resource/3>}\n```","ref":"Anthropix.html#chat/2-examples"},{"type":"type","title":"Anthropix.client/0","doc":"Client struct","ref":"Anthropix.html#t:client/0"},{"type":"type","title":"Anthropix.content_block/0","doc":"Message content block.","ref":"Anthropix.html#t:content_block/0"},{"type":"type","title":"Anthropix.content_media/0","doc":"","ref":"Anthropix.html#t:content_media/0"},{"type":"type","title":"Anthropix.content_text/0","doc":"","ref":"Anthropix.html#t:content_text/0"},{"type":"type","title":"Anthropix.content_tool_result/0","doc":"","ref":"Anthropix.html#t:content_tool_result/0"},{"type":"type","title":"Anthropix.content_tool_use/0","doc":"","ref":"Anthropix.html#t:content_tool_use/0"},{"type":"function","title":"Anthropix.init/0","doc":"Calling `init/1` without passing an API key, creates a new Anthropix API\nclient using the API key set in your application's config.\n\n```elixir\nconfig :anthropix, :api_key, \"sk-ant-your-key\"\n```\n\nIf given, a keyword list of options will be passed to `Req.new/1`.","ref":"Anthropix.html#init/0"},{"type":"function","title":"Examples - Anthropix.init/0","doc":"```elixir\niex> client = Anthropix.init()\n%Anthropix{}\n```","ref":"Anthropix.html#init/0-examples"},{"type":"function","title":"Anthropix.init/1","doc":"","ref":"Anthropix.html#init/1"},{"type":"function","title":"Anthropix.init/2","doc":"Calling `init/2` with an API key creates a new Anthropix API client, using the\ngiven API key. Optionally, a keyword list of options can be passed through to\n`Req.new/1`.\n\n##","ref":"Anthropix.html#init/2"},{"type":"function","title":"Examples - Anthropix.init/2","doc":"```elixir\niex> client = Anthropix.init(\"sk-ant-your-key\", receive_timeout: :infinity)\n%Anthropix{}\n```","ref":"Anthropix.html#init/2-examples"},{"type":"type","title":"Anthropix.input_schema/0","doc":"JSON schema for the tool `input` shape.","ref":"Anthropix.html#t:input_schema/0"},{"type":"type","title":"Anthropix.message/0","doc":"Chat message\n\nA chat message is a `t:map/0` with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `user` or `assistant`.\n* `:content` - Required. Message content, either a single string or an array of content blocks.","ref":"Anthropix.html#t:message/0"},{"type":"type","title":"Anthropix.response/0","doc":"Client response","ref":"Anthropix.html#t:response/0"},{"type":"type","title":"Anthropix.tool/0","doc":"Tool.\n\nA chat tool is a `t:map/0` with the following fields:\n\n* `:name` (`t:String.t/0`) - Required. Name of the tool.\n* `:description` (`t:String.t/0`) - Required. Description of the tool\n* `:input_schema` - Required. JSON schema for the tool input shape that the model will produce in tool_use output content blocks.\n* `:cache_control` - Cache-control parameter.","ref":"Anthropix.html#t:tool/0"},{"type":"module","title":"Anthropix.Batch","doc":"The [message batches API](https://docs.anthropic.com/en/docs/build-with-claude/message-batches)\nis a powerful, cost-effective way to asynchronously process large volumes of\nmessages requests. This approach is well-suited to tasks that do not require\nimmediate responses, reducing costs by 50% while increasing throughput.","ref":"Anthropix.Batch.html"},{"type":"function","title":"Anthropix.Batch.cancel/2","doc":"Cancels a message batch before processing ends. Depending on when cancellation\nis initiated, the number of cancelled messages requests will vary.","ref":"Anthropix.Batch.html#cancel/2"},{"type":"function","title":"Examples - Anthropix.Batch.cancel/2","doc":"```elixir\niex> Anthropix.Batch.cancel(client, \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\")\n{:ok, %{\n  \"type\" => \"message_batch\",\n  \"id\" => \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\"\n  \"processing_status\" => \"canceling\",\n  ...\n}}\n```","ref":"Anthropix.Batch.html#cancel/2-examples"},{"type":"function","title":"Anthropix.Batch.create/2","doc":"Send a batch of message creation requests. Used to process multiple message\nrequests in a single batch. Processing begins immediately.","ref":"Anthropix.Batch.html#create/2"},{"type":"function","title":"Options - Anthropix.Batch.create/2","doc":"* `:requests` (list of `t:map/0`) - Required. List of requests for prompt completion.","ref":"Anthropix.Batch.html#create/2-options"},{"type":"function","title":"Examples - Anthropix.Batch.create/2","doc":"```elixir\niex> Anthropix.Batch.create(client, [\n...>   %{custom_id: \"foo\", params: %{model: \"claude-3-haiku-20240307\", messages: [%{role: \"user\", content: \"Why is the sky blue?\"}]}},\n...>   %{custom_id: \"bar\", params: %{model: \"claude-3-haiku-20240307\", messages: [%{role: \"user\", content: \"Why is the sea blue?\"}]}},\n...> ])\n{:ok, %{\n  \"type\" => \"message_batch\",\n  \"id\" => \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\"\n  \"processing_status\" => \"in_progress\",\n  ...\n}}\n```","ref":"Anthropix.Batch.html#create/2-examples"},{"type":"function","title":"Anthropix.Batch.list/2","doc":"List all message batches. Most recently created batches are returned first.","ref":"Anthropix.Batch.html#list/2"},{"type":"function","title":"Options - Anthropix.Batch.list/2","doc":"* `:before_id` (`t:String.t/0`) - Returns the page of results immediately before this object.\n* `:after_id` (`t:String.t/0`) - Returns the page of results immediately after this object.\n* `:limit` (`t:integer/0`) - Number of items to return per page. Between 1-100 (default 20).","ref":"Anthropix.Batch.html#list/2-options"},{"type":"function","title":"Examples - Anthropix.Batch.list/2","doc":"```elixir\niex> Anthropix.Batch.list(client)\n{:ok, %{\"data\" => [...]}}\n\n# With pagination options\niex> Anthropix.Batch.list(client, after_id: \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\", limit: 50)\n{:ok, %{\"data\" => [...]}}\n```","ref":"Anthropix.Batch.html#list/2-examples"},{"type":"function","title":"Anthropix.Batch.results/3","doc":"Retrieve the status of the batch. Will respond with or stream a list of chat\nmessage completions.\n\nIt is preferred to pass the result of `show/2` directly, but also accepts a\n`results_url` or `batch_id` string.\n\nResults are not guaranteed to be in the same order as requests. Use the\n`custom_id` field to match results to requests.","ref":"Anthropix.Batch.html#results/3"},{"type":"function","title":"Options - Anthropix.Batch.results/3","doc":"* `:requests` (list of `t:map/0`) - Required. List of requests for prompt completion.","ref":"Anthropix.Batch.html#results/3-options"},{"type":"function","title":"Examples - Anthropix.Batch.results/3","doc":"```elixir\niex> Anthropix.Batch.results(client, \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\")\n{:ok, [\n  %{\"custom_id\" => \"foo\", \"result\" => %{...}},\n  %{\"custom_id\" => \"bar\", \"result\" => %{...}},\n]}\n\n# Passing true to the :stream option initiates an async streaming request.\niex> Anthropix.Batch.results(client, \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\", stream: true)\n{:ok, #Function<52.53678557/2 in Stream.resource/3>}\n```","ref":"Anthropix.Batch.html#results/3-examples"},{"type":"function","title":"Anthropix.Batch.show/2","doc":"Retrieve the status of the batch. Can be used to poll for message batch\ncompletion.\n\nWhen the batch is ready, the `\"processing_status\"` will be `\"ended\"` and the\nresponse will include a `\"results_url\"` value.","ref":"Anthropix.Batch.html#show/2"},{"type":"function","title":"Examples - Anthropix.Batch.show/2","doc":"```elixir\niex> Anthropix.Batch.show(client, \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\")\n{:ok, %{\n  \"type\" => \"message_batch\",\n  \"id\" => \"msgbatch_01DJuZbTFXpGRhqTdqFH1P2R\"\n  \"processing_status\" => \"ended\",\n  \"results_url\" => \"https://api.anthropic.com/v1/messages/batches/msgbatch_01DJuZbTFXpGRhqTdqFH1P2R/results\",\n  ...\n}}\n```","ref":"Anthropix.Batch.html#show/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}